Welcome to Shape4D’s documentation! — Shape4D 0.08 documentation

The aims at predicting shadows of solar beam on windows/walls in building or on panels of solar cells/collectors, and we first defined some geometrical functions specific for the purpose.

- About Shape4D
  - Functions of Shape4D
- Installation
  - Preparation
  - Install the package
- Get started
  - Drawing the logo of Shape4D

- Visual shapes
  - Point
  - Line
  - Polygon
  - Transformation
- Shapes in depth
  - Shapes
  - A complex shape
  - From 2D to 3D space
  - Examples
- Functions about point inside shapes
  - Point(s) in a line
  - Point(s) in a plane
- Functions about line across shapes
  - Line vs line
  - Line vs plane
  - Line vs polygon
- Functions about precision control

# Memo

Welcome to any reply !

# Reference list

- Index

- Search Page